/* ------------------------------------------------------------------------- */
/* FTEST144.CMD    - FVT FORMAT Testcase for 1.44 Diskette Drives            */
/*                                                                           */
/* Filename=FTEST.CMD      Dept. F9KA             5/16/96                    */
/*                                                                           */
/* Description:  This batch file tests OS/2 format commands                  */
/*               against a diskette drive.  A 1.44MB diskette                */
/*               media must be mounted in the A: drive.                      */
/*               The initial tests are error tests.  They                    */
/*               are expected to result in an OS/2 error                     */
/*               message.  The first non-error format is a                   */
/*               low-level full format.  This and subsequent                 */
/*               format tests should not result in errors.                   */
/*               The monitor result statements are captured                  */
/*               and logged to \LOGF\DSKTRSLT.LOG after each format test.    */
/*               The screen is cleared before each test.                     */
/*               Each format duration is timed.                              */
/*                                                                           */
/* Contents:  FTEST.CMD - the batch utility                                  */
/*            MARK.EXE  - a date/time stamp program                          */
/*            SNAP.EXE  - a screen capture program                           */
/*            SS.EXE    - an interval timer                                  */
/*            STDCHG.COM - a message redirector                              */
/*            *.IN      - various pseudo keyboard inputs                     */
/*                                                                           */
/* Operation:  Start by copying all test modules to a hard-disk              */
/*             directory and then from this directory enter                  */
/*             FTEST.  1.44MB media must be mounted in A drive.              */
/*             Results will be logged to file \LOGF\DSKTRSLT.LOG             */
/*                                                                           */
/*    Uses OS2 environment variables to determine testcase drive.            */
/* ------------------------------------------------------------------------- */
'@echo off'
'cls'
say ''
arg parm comments
if left(parm,1) = '?' then signal INFO_PLEASE

/* ------------------------------------------------------------------------- */
os2drv = value('PCM_BOOTDRV',,'OS2ENVIRONMENT');       /* get OS2 boot drive */
tstdrv = value('PCM_TESTDRV',,'OS2ENVIRONMENT');       /* get testcase drive */
if pos(os2drv,'CDEFGHIJKLMNOPQRSTUVWXYZ') = 0 then do
   say '[1;09;41m ***************************************************************[0;40;37m'
   say '[1;09;41m * OS2 environment variable PCM_BOOTDRV not set.  Run PCMSETUP *[0;40;37m'
   say '[1;09;41m * to update config.sys, then shutdown & reboot to continue.   *[0;40;37m'
   say '[1;09;41m ***************************************************************[0;40;37m'
   exit
   end
if pos(tstdrv,'CDEFGHIJKLMNOPQRSTUVWXYZ') = 0 then do
   say '[1;09;41m ***************************************************************[0;40;37m'
   say '[1;09;41m * OS2 environment variable PCM_TESTDRV not set.  Run PCMSETUP *[0;40;37m'
   say '[1;09;41m * to update config.sys, then shutdown & reboot to continue.   *[0;40;37m'
   say '[1;09;41m ***************************************************************[0;40;37m'
   exit
   end

/* ------------------------------------------------------------------------- */
tstdrv':'
if stream(tstdrv':\logf','c','query size') >= 0 then do
   say 'LOGF directory found'
   end
else
   do
   say 'making LOGF directory'
   'mkdir 'tstdrv':\logf'
   end

/* ------------------------------------------------------------------------- */
rc = RXFUNCADD('SysLoadFuncs', 'RexxUtil', 'SysLoadFuncs')
call SysLoadFuncs
/* ------------------------------------------------------------------------- */
tstdrv':'
'cd \format'
/* ------------------------------------------------------------------------- */
info = SysDriveInfo('A:')
/* ------------------------------------------------------------------------- */
if info = '' then do
   say ''
   say '[1;41;31m|||||||||||||||||||||||||||||||||||||||||||[1;42;37m'
   say ''
   say '[1;44;37mReady to run FVT 1.44MB FORMAT Testcases...[0;40;37m'
   say ''
   say '[1;44;37mInsert a scratch diskette in A:............[0;40;37m'
   say ''
   say '[1;44;37mMake sure diskette is not write protected..[0;40;37m'
   say ''
   say '[1;44;37mTo TEST 1.44MB DRIVE OTHER THAN A: You need [0;40;37m'
   say '[1;44;37mto edit the .INP file and change the a: to  [0;40;37m'
   say '[1;44;37mthe drive letter to be tested.              [0;40;37m'
   say '[1;44;37m        REFER TO \FORMAT\README.FMT         [0;40;37m'
   say ''
   say '[1;41;31m|||||||||||||||||||||||||||||||||||||||||||[0;40;37m'
   pause
   end
/* ------------------------------------------------------------------------- */
'DEL \LOGF\DSKTRSLT.LOG >> NUL'

'MARK  > \LOGF\DSKTRSLT.LOG'
'ECHO. >> \LOGF\DSKTRSLT.LOG'
'ECHO ---------------------------------------------------------------- >> \LOGF\DSKTRSLT.LOG'
'ECHO OS/2 DISKETTE FORMAT UTILITY ERROR TEST RESULTS >> \LOGF\DSKTRSLT.LOG'
'ECHO ---------------------------------------------------------------- >> \LOGF\DSKTRSLT.LOG'
'ECHO. >> \LOGF\DSKTRSLT.LOG'
'ECHO. >> \LOGF\DSKTRSLT.LOG'

'CLS'
'ECHO Format Error Test 1 - Running ....'
'ECHO ---------------------------------------------------------------- >> \LOGF\DSKTRSLT.LOG'
'ECHO Format Error Test 1 >> \LOGF\DSKTRSLT.LOG'
'ECHO Expecting "The FORMAT command has detected an incorrect parameter" error for /1 >> \LOGF\DSKTRSLT.LOG'
'FORMAT A: /1 <ENTERN.IN'
'SNAP \LOGF\DSKTRSLT.LOG /a /m /q'
'ECHO Format Error Test 1 - Ended'
'ECHO. >> \LOGF\DSKTRSLT.LOG'

'CLS'
'ECHO Format Error Test 2 - Running ....'
'ECHO ---------------------------------------------------------------- >> \LOGF\DSKTRSLT.LOG'
'ECHO Format Error Test 2 >> \LOGF\DSKTRSLT.LOG'
'ECHO Expecting "The FORMAT command has detected an incorrect parameter" error for /4 >> \LOGF\DSKTRSLT.LOG'
'FORMAT A: /4 <ENTERN.IN'
'SNAP \LOGF\DSKTRSLT.LOG /a /m /q'
'ECHO Format Error Test 2 - Ended'
'ECHO. >> \LOGF\DSKTRSLT.LOG'

'CLS'
'ECHO Format Error Test 3 - Running ....'
'ECHO ---------------------------------------------------------------- >> \LOGF\DSKTRSLT.LOG'
'ECHO Format Error Test 3 >> \LOGF\DSKTRSLT.LOG'
'ECHO Expecting "The FORMAT command has detected an incorrect parameter" error for /8 >> \LOGF\DSKTRSLT.LOG'
'FORMAT A: /8< ENTERN.IN'
'SNAP \LOGF\DSKTRSLT.LOG /a /m /q'
'ECHO Format Error Test 3 - Ended'
'ECHO. >> \LOGF\DSKTRSLT.LOG'

'CLS'
'ECHO Format Error Test 4 - Running ....'
'ECHO ---------------------------------------------------------------- >> \LOGF\DSKTRSLT.LOG'
'ECHO Format Error Test 4 >> \LOGF\DSKTRSLT.LOG'
'ECHO Expecting "The FORMAT command has detected an incorrect parameter" error for /B >> \LOGF\DSKTRSLT.LOG'
'FORMAT A: /B /V:dasdtest < ENTERN.IN'
'SNAP \LOGF\DSKTRSLT.LOG /a /m /q'
'ECHO Format Error Test 4 - Ended'
'ECHO. >> \LOGF\DSKTRSLT.LOG'

'CLS'
'ECHO Format Error Test 5 - Running ....'
'ECHO ---------------------------------------------------------------- >> \LOGF\DSKTRSLT.LOG'
'ECHO Format Error Test 5 >> \LOGF\DSKTRSLT.LOG'
'ECHO Expecting "The FORMAT command has detected an incorrect parameter" error for /FS >> \LOGF\DSKTRSLT.LOG'
'ECHO Or "An incorrect volume label was entered for this drive"  >> \LOGF\DSKTRSLT.LOG'
'FORMAT A: /FS:HPFS < HPFS.IN'
'SNAP \LOGF\DSKTRSLT.LOG /a /m /q'
'ECHO Format Error Test 5 - Ended'
'ECHO. >> \LOGF\DSKTRSLT.LOG'

'CLS'
'ECHO Format Error Test 6 - Running ....'
'ECHO ---------------------------------------------------------------- >> \LOGF\DSKTRSLT.LOG'
'ECHO Format Error Test 6 >> \LOGF\DSKTRSLT.LOG'
'ECHO Expecting "The FORMAT command has detected an incorrect parameter" error for /n >> \LOGF\DSKTRSLT.LOG'
'FORMAT A: /n:100 < ENTERN.IN'
'SNAP \LOGF\DSKTRSLT.LOG /a /m /q'
'ECHO Format Error Test 6 - Ended'
'ECHO. >> \LOGF\DSKTRSLT.LOG'

'CLS'
'ECHO Format Error Test 7 - Running ....'
'ECHO ---------------------------------------------------------------- >> \LOGF\DSKTRSLT.LOG'
'ECHO Format Error Test 7 >> \LOGF\DSKTRSLT.LOG'
'ECHO Expecting "The FORMAT command has detected an incorrect parameter" error for /t >> \LOGF\DSKTRSLT.LOG'
'FORMAT A: /t:9999 < ENTERN.IN'
'SNAP \LOGF\DSKTRSLT.LOG /a /m /q'
'ECHO Format Error Test 7 - Ended'
'ECHO. >> \LOGF\DSKTRSLT.LOG'

'CLS'
'ECHO Format Error Test 8 - Running ....'
'ECHO ---------------------------------------------------------------- >> \LOGF\DSKTRSLT.LOG'
'ECHO Format Error Test 8 >> \LOGF\DSKTRSLT.LOG'
'ECHO Expecting "The FORMAT command has detected an incorrect parameter" error for /n >> \LOGF\DSKTRSLT.LOG'
'FORMAT A: /n:0 < ENTERN.IN'
'SNAP \LOGF\DSKTRSLT.LOG /a /m /q'
'ECHO Format Error Test 8 - Ended'
'ECHO. >> \LOGF\DSKTRSLT.LOG'

'CLS'
'ECHO Format Error Test 9 - Running ....'
'ECHO ---------------------------------------------------------------- >> \LOGF\DSKTRSLT.LOG'
'ECHO Format Error Test 9 >> \LOGF\DSKTRSLT.LOG'
'ECHO Expecting "The FORMAT command has detected an incorrect parameter" error for /t >> \LOGF\DSKTRSLT.LOG'
'FORMAT A: /t:0 < ENTERN.IN'
'SNAP \LOGF\DSKTRSLT.LOG /a /m /q'
'ECHO Format Error Test 9 - Ended'
'ECHO. >> \LOGF\DSKTRSLT.LOG'

'CLS'
'ECHO Format Error Test 10 - Running ....'
'ECHO ---------------------------------------------------------------- >> \LOGF\DSKTRSLT.LOG'
'ECHO Format Error Test 10 >> \LOGF\DSKTRSLT.LOG'
'ECHO Expecting "The FORMAT command has detected an incorrect parameter" error for /n >> \LOGF\DSKTRSLT.LOG'
'FORMAT A: /n:-1 < ENTERN.IN'
'SNAP \LOGF\DSKTRSLT.LOG /a /m /q'
'ECHO Format Error Test 10 - Ended'
'ECHO. >> \LOGF\DSKTRSLT.LOG'

'CLS'
'ECHO Format Error Test 11 - Running ....'
'ECHO ---------------------------------------------------------------- >> \LOGF\DSKTRSLT.LOG'
'ECHO Format Error Test 11 >> \LOGF\DSKTRSLT.LOG'
'ECHO Expecting "The FORMAT command has detected an incorrect parameter" error for /t >> \LOGF\DSKTRSLT.LOG'
'FORMAT A: /t:-1 < ENTERN.IN'
'SNAP \LOGF\DSKTRSLT.LOG /a /m /q'
'ECHO Format Error Test 11 - Ended'
'ECHO. >> \LOGF\DSKTRSLT.LOG'

'CLS'
'ECHO Format Error Test 12 - Running ....'
'ECHO ---------------------------------------------------------------- >> \LOGF\DSKTRSLT.LOG'
'ECHO Format Error Test 12 >> \LOGF\DSKTRSLT.LOG'
'ECHO Expecting "The FORMAT command has detected an incorrect parameter" error for /f >> \LOGF\DSKTRSLT.LOG'
'FORMAT A: /f:360 < ENTERN.IN'
'SNAP \LOGF\DSKTRSLT.LOG /a /m /q'
'ECHO Format Error Test 12 - Ended'
'ECHO. >> \LOGF\DSKTRSLT.LOG'

'CLS'
'ECHO Format Error Test 13 - Running ....'
'ECHO ---------------------------------------------------------------- >> \LOGF\DSKTRSLT.LOG'
'ECHO Format Error Test 13 >> \LOGF\DSKTRSLT.LOG'
'ECHO Expecting "The FORMAT command has detected an incorrect parameter" error for /f >> \LOGF\DSKTRSLT.LOG'
'FORMAT A: /f: < ENTERN.IN'
'SNAP \LOGF\DSKTRSLT.LOG /a /m /q'
'ECHO Format Error Test 13 - Ended'
'ECHO. >> \LOGF\DSKTRSLT.LOG'

'CLS'
'ECHO Format Error Test 14 - Running ....'
'ECHO ---------------------------------------------------------------- >> \LOGF\DSKTRSLT.LOG'
'ECHO Format Error Test 14 >> \LOGF\DSKTRSLT.LOG'
'ECHO Expecting "The FORMAT command has detected an incorrect parameter" error for /f >> \LOGF\DSKTRSLT.LOG'
'FORMAT A: /f:2.88 < ENTERN.IN'
'SNAP \LOGF\DSKTRSLT.LOG /a /m /q'
'ECHO Format Error Test 14 - Ended'
'ECHO. >> \LOGF\DSKTRSLT.LOG'

'CLS'
'ECHO Format Error Test 15 - Running ....'
'ECHO ---------------------------------------------------------------- >> \LOGF\DSKTRSLT.LOG'
'ECHO Format Error Test 15 >> \LOGF\DSKTRSLT.LOG'
'ECHO Expecting "The FORMAT command has detected an incorrect parameter" error for /F >> \LOGF\DSKTRSLT.LOG'
'FORMAT A: /F:180 < ENTERN.IN'
'SNAP \LOGF\DSKTRSLT.LOG /a /m /q'
'ECHO Format Error Test 15 - Ended'
'ECHO. >> \LOGF\DSKTRSLT.LOG'

'ECHO. >> \LOGF\DSKTRSLT.LOG'
'ECHO. >> \LOGF\DSKTRSLT.LOG'
'ECHO. >> \LOGF\DSKTRSLT.LOG'
'ECHO. >> \LOGF\DSKTRSLT.LOG'
'ECHO ---------------------------------------------------------------- >> \LOGF\DSKTRSLT.LOG'
'ECHO OS/2 DISKETTE FORMAT UTILITY STANDARD TEST RESULTS >> \LOGF\DSKTRSLT.LOG'
'ECHO ---------------------------------------------------------------- >> \LOGF\DSKTRSLT.LOG'
'ECHO. >> \LOGF\DSKTRSLT.LOG'
'ECHO. >> \LOGF\DSKTRSLT.LOG'

'CLS'
'ECHO Initial Diskette Format ....'
'ECHO ---------------------------------------------------------------- >> \LOGF\DSKTRSLT.LOG'
'ECHO Diskette Initialization >> \LOGF\DSKTRSLT.LOG'
'ECHO Expecting Low-level or Verify Format >> \LOGF\DSKTRSLT.LOG'
'SS START'
'FORMAT A: /L /V:DASDTEST < ENTERN.IN'
'SS STOP Format with /L >> \LOGF\DSKTRSLT.LOG'
'ECHO. >> \LOGF\DSKTRSLT.LOG'
'SNAP \LOGF\DSKTRSLT.LOG /a /m /q'
'ECHO Initialization - Ended'
'ECHO. >> \LOGF\DSKTRSLT.LOG'

'CLS'
'ECHO Format Standard Test 1 - Running ....'
'ECHO ---------------------------------------------------------------- >> \LOGF\DSKTRSLT.LOG'
'ECHO Format Standard Test 1 >> \LOGF\DSKTRSLT.LOG'
'ECHO Expecting Low-Level Format >> \LOGF\DSKTRSLT.LOG'
'SS START'
'FORMAT A: /V:DASDTEST < ENTERN.IN'
'SS STOP Format with no parms >> \LOGF\DSKTRSLT.LOG'
'ECHO. >> \LOGF\DSKTRSLT.LOG'
'SNAP \LOGF\DSKTRSLT.LOG /a /m /q'
'ECHO Format Standard Test 1 - Ended'
'ECHO. >> \LOGF\DSKTRSLT.LOG'
'ECHO. >> \LOGF\DSKTRSLT.LOG'

'CLS'
'ECHO Format Standard Test 2 - Running ....'
'ECHO ---------------------------------------------------------------- >> \LOGF\DSKTRSLT.LOG'
'ECHO Format Standard Test 2 >> \LOGF\DSKTRSLT.LOG'
'ECHO Expecting Single Format for /ONCE >> \LOGF\DSKTRSLT.LOG'
'SS START'
'FORMAT A: /ONCE /V:DASDTEST'
'SS STOP Format with /ONCE >> \LOGF\DSKTRSLT.LOG'
'ECHO. >> \LOGF\DSKTRSLT.LOG'
'SNAP \LOGF\DSKTRSLT.LOG /a /m /q'
'ECHO Format Standard Test 2 - Ended'
'ECHO. >> \LOGF\DSKTRSLT.LOG'

'CLS'
'ECHO Format Standard Test 3 - Running ....'
'ECHO ---------------------------------------------------------------- >> \LOGF\DSKTRSLT.LOG'
'ECHO Format Standard Test 3 >> \LOGF\DSKTRSLT.LOG'
'ECHO Expecting Reduced Format for /R >> \LOGF\DSKTRSLT.LOG'
'SS START'
'FORMAT A: /R /V:DASDTEST < ENTERN.IN'
'SS STOP Format with /R >> \LOGF\DSKTRSLT.LOG'
'ECHO. >> \LOGF\DSKTRSLT.LOG'
'SNAP \LOGF\DSKTRSLT.LOG /a /m /q'
'ECHO Format Standard Test 3 - Ended'
'ECHO. >> \LOGF\DSKTRSLT.LOG'

'CLS'
'ECHO Format Standard Test 4 - Running ....'
'ECHO ---------------------------------------------------------------- >> \LOGF\DSKTRSLT.LOG'
'ECHO Format Standard Test 4 >> \LOGF\DSKTRSLT.LOG'
'ECHO Expecting Quick Format for /Q >> \LOGF\DSKTRSLT.LOG'
'SS START'
'FORMAT A: /Q  < VOLUME.IN'
'SS STOP Format with /Q >> \LOGF\DSKTRSLT.LOG'
'ECHO. >> \LOGF\DSKTRSLT.LOG'
'SNAP \LOGF\DSKTRSLT.LOG /a /m /q'
'ECHO Format Standard Test 4 - Ended'
'ECHO. >> \LOGF\DSKTRSLT.LOG'

'CLS'
'ECHO Format Standard Test 5 - Running ....'
'ECHO ---------------------------------------------------------------- >> \LOGF\DSKTRSLT.LOG'
'ECHO Format Standard Test 5 >> \LOGF\DSKTRSLT.LOG'
'ECHO Expecting FAT Format for /FS:FAT >> \LOGF\DSKTRSLT.LOG'
'SS START'
'FORMAT A: /FS:FAT /V:DASDTEST < ENTERN.IN'
'SS STOP Format with /FS:FAT >> \LOGF\DSKTRSLT.LOG'
'ECHO. >> \LOGF\DSKTRSLT.LOG'
'SNAP \LOGF\DSKTRSLT.LOG /a /m /q'
'ECHO Format Standard Test 5 - Ended'
'ECHO. >> \LOGF\DSKTRSLT.LOG'

'CLS'
'ECHO Format Standard Test 6 - Running ....'
'ECHO ---------------------------------------------------------------- >> \LOGF\DSKTRSLT.LOG'
'ECHO Format Standard Test 6 >> \LOGF\DSKTRSLT.LOG'
'ECHO Expecting Low-Level Format for /T:80 /N:18 >> \LOGF\DSKTRSLT.LOG'
'SS START'
'FORMAT A: /V:dasdtest < ENTERN.IN'
'SS STOP Format with /T:80 /N:18 >> \LOGF\DSKTRSLT.LOG'
'ECHO. >> \LOGF\DSKTRSLT.LOG'
'SNAP \LOGF\DSKTRSLT.LOG /a /m /q'
'ECHO Format Standard Test 6 - Ended'
'ECHO. >> \LOGF\DSKTRSLT.LOG'

'CLS'
'ECHO Format Standard Test 7 - Running ....'
'ECHO ---------------------------------------------------------------- >> \LOGF\DSKTRSLT.LOG'
'ECHO Format Standard Test 7 >> \LOGF\DSKTRSLT.LOG'
'ECHO Expecting Low-Level Format for /F:1440 >> \LOGF\DSKTRSLT.LOG'
'SS START'
'FORMAT A: /V:dasdtest < ENTERN.IN'
'SS STOP Format with /F:1440 >> \LOGF\DSKTRSLT.LOG'
'ECHO. >> \LOGF\DSKTRSLT.LOG'
'SNAP \LOGF\DSKTRSLT.LOG /a /m /q'
'ECHO Format Standard Test 7 - Ended'
'ECHO. >> \LOGF\DSKTRSLT.LOG'
'ECHO ----------------------------------------------------------------'
'ECHO See log file "\LOGF\DSKTRSLT.LOG" for test results'
'ECHO ----------------------------------------------------------------'
'COPY \SCRIPT\FLOP144.SCR A:\'
'ECHO ----------------------------------------------------------------'
exit
/*-------------------------------------------------------------------------- */
INFO_PLEASE:
  say '[1;26;45m  ͻ  '
  say '   FTEST144.CMD - FVT level testcase for 1.44MB diskette drive.       '
  say '                                                                      '
  say '   Parameters: NONE                                                   '
  say '                                                                      '
  say '   Requires SCRATCH DISKETTE in drive A: - WITH WRITE PROTECT OFF     '
  say '                                                                      '
  say '   Uses OS/2 environment variables to determine testcase drive.       '
  say '  ͼ  [0;40;37m'
  exit
