/*****************************************************************************
*
*                            IBM Confidential
*
*  TEST CASE NAME   :   PRT_A41
*
*  DESCRIPTIVE NAME :   AUTOMATED TEST
*
*  DESCRIPTION AND PURPOSE :
*
*  PRT_A41 sends various sizes of data to the printer using the DOSWRITE
*  function call.  The buffer sizes sent include: 0b, 1b, 255b, 256b, 257b
*  and 512b.  Some of the data sent include escape sequences and control
*  characters.
*
*  HARDWARE AND SOFTWARE REQUIREMENTS :
*
*     PC/AT's  with combinations of Color, Graphics, and Pro printers.
*
*  EXECUTION INSTRUCTIONS :
*
*     The testcase is written in accordance with the Microsoft test case
*  standard.  To execute this testcase simply type the test case name followed
*  by the logging level, the logfile name and the -a option if applicable.
*  Optional parameters can be used to specify the port and the number of the
*  test about to be run.  If a -n# parameter is used, where # is any two digit
*  number, the testcase will print out that number on every DOSWRITE it makes
*  to the printer.
*
*  If a -p# parameter is used, where # is a number from 1 to 3, the testcase
*  will test to that port.  A menu will come up and prompt the operator if
*  these parameters are not used.
*
*  TEST CASE WRITER :  BRYAN WRIGHT
*
*  TEST CASE OWNER  :  JANET DMITROVICH
*
************************ END OF SPECIFICATIONS ******************************/

#include <stdio.h>
#include <doscalls.h>
#include <print_dd.h>
#include <mstlogn.h>
#include <error.h>
#include <error2.h>
#include <data.h>


main(argc, argv)

  int argc;
  char *argv[];

{

  strcpy (buff6, buff4);      /* 256 bytes */
  strcat (buff6, buff6);      /* 512 bytes */

  initialize_test (argc, argv, 2, "PRT_A41", "Character data test A41\n");

/****************************************************************************
*                     SET TEST CASE NUMBER ACCORDINGLY
*****************************************************************************/

  buff1[10] = 4;   /* SET THE NUMBER OF THE TEST, IT */
  buff1[11] = 1;   /* WILL BE PRINTED OUT ON EACH    */
  buff2[12] = 4;   /* DOSWRITE THE TESTCASE MAKES    */
  buff2[13] = 1;
  buff3[12] = 4;
  buff3[13] = 1;
  buff4[12] = 4;
  buff4[13] = 1;
  buff5[12] = 4;
  buff5[13] = 1;
  buff6[12] = 4;
  buff6[13] = 1;
  buff7[10] = 4;
  buff7[11] = 1;
  buff8[10] = 4;
  buff8[11] = 1;

/****************************************************************************
*            SENDING 0 BYTES OF DATA TO PORT (BEGIN VARIATION #1)
*****************************************************************************/

VARLOG (1);

  CWRITELOG (L_TRACE, (l_log, "Sending  0  bytes to port\n"));

  rc = DOSWRITE (handle,
                 (char far *) "",
                 0,
                 (unsigned far *) &num_bytes);

  if (rc || (0 != num_bytes)) {
    CWRITELOG (L_FAIL, (l_log, "ERROR on DOSWRITE 0, rc is %#x.\n",rc));
    pass_fail = 'F';
  }

/****************************************************************************
*             SENDING 1 BYTE OF DATA TO PORT (BEGIN VARIATION #2)
*****************************************************************************/

VARLOG (2);

  CWRITELOG (L_TRACE, (l_log, "Sending 1 byte to port\n"));

  rc = DOSWRITE (handle,
                 (char far *) buff1,
                 strlen (buff1),
                 (unsigned far *) &num_bytes);

  if (rc || (strlen (buff1) != num_bytes)) {
    CWRITELOG (L_FAIL, (l_log, "Error on DOSWRITE 1, rc is %#x.\n",rc));
    pass_fail = 'F';
  }

  rc = DOSWRITE (handle, " ", strlen (buff2), (unsigned far *)&num_bytes);

  if (rc || (strlen (buff2) != num_bytes)) {
    CWRITELOG (L_FAIL, (l_log, "Error on DOSWRITE 2, rc is %#x.\n",rc));
    pass_fail = 'F';
  }

  rc = DOSWRITE (handle, "ce in the word space.\n\n", 23, (unsigned far *)&num_bytes);

  if (rc || (23 != num_bytes)) {
    CWRITELOG (L_FAIL, (l_log, "Error on DOSWRITE 3, rc is %#x.\n",rc));
    pass_fail = 'F';
  }

/****************************************************************************
*                              END VARIATION #2
*****************************************************************************/

/****************************************************************************
*          SENDING 256 BYTES OF DATA TO PORT (BEGIN VARIATION #3)
*****************************************************************************/

VARLOG (3);

  CWRITELOG (L_TRACE, (l_log, "Sending 256 bytes to port\n"));

  rc = DOSWRITE (handle,
                 (char far *) buff4,
                 strlen (buff4),
                 (unsigned far *) &num_bytes);

  if (rc || (strlen (buff4) != num_bytes)) {
    CWRITELOG (L_FAIL, (l_log, "Error on DOSWRITE, rc is %#x.\n",rc));
    pass_fail = 'F';
  }

/****************************************************************************
*                           END VARIATION #3
*****************************************************************************/

/****************************************************************************
*      SENDING 257 BYTES OF DATA TO PORT (BEGIN VARIATION #4)
*****************************************************************************/

VARLOG (4);

  CWRITELOG (L_TRACE, (l_log, "Sending 257 bytes to port\n"));

  rc = DOSWRITE (handle,
                 (char far *) buff5,
                 strlen (buff5),
                 (unsigned far *) &num_bytes);

  if (rc || (strlen (buff5) != num_bytes)){
    CWRITELOG (L_FAIL, (l_log, "Error on DOSWRITE, rc is %#x.\n",rc));
    pass_fail = 'F';
  }

/****************************************************************************
*                          END VARIATION #4
*****************************************************************************/

/****************************************************************************
*           SENDING 512 BYTES OF DATA TO PORT (BEGIN VARIATION #5)
*****************************************************************************/

VARLOG (5);

  CWRITELOG (L_TRACE, (l_log, "Sending 512 bytes to port\n"));

  rc = DOSWRITE (handle,
                 (char far *) buff6,
                 strlen (buff6),
                 (unsigned far *) &num_bytes);

  if (rc || (strlen (buff6) != num_bytes)) {
    CWRITELOG (L_FAIL, (l_log, "Error on DOSWRITE, rc is %#x.\n",rc));
    pass_fail = 'F';
  }

/****************************************************************************
*                               END VARIATION #5
*****************************************************************************/

/****************************************************************************
*             SEND EMPHASIZED ESCAPE SEQUENCES (BEGIN VARIATION #6)
*****************************************************************************/

VARLOG (6);

  CWRITELOG (L_TRACE, (l_log, "Sending Emphasized to port\n"));

  rc = DOSWRITE (handle,
                 (char far *) buff7,
                 strlen (buff7),
                 (unsigned far *) &num_bytes);

  if (rc || (strlen (buff7) != num_bytes)) {
    CWRITELOG (L_FAIL, (l_log, "Error on emphasized write, rc is %#x.\n",rc));
    pass_fail = 'F';
  }

/****************************************************************************
*                                  END VARIATION #6
*****************************************************************************/

/****************************************************************************
*            SEND LOTS OF ESCAPE SEQUENCES (BEGIN VARIATION #7)
*****************************************************************************/

VARLOG (7);

  CWRITELOG (L_TRACE, (l_log, "Sending underline, double struck,overscore to Port.\n"));      /* ONLY WORKS FOR THE PRO PRINTER */

  rc = DOSWRITE (handle,
                 (char far *) buff8,
                 strlen (buff8),
                 (unsigned far *) &num_bytes);

  if (rc || (strlen (buff8) != num_bytes)) {
    CWRITELOG (L_FAIL, (l_log, "Error on underline, double struck, overscored, rc is %#x.\n",rc));
    pass_fail = 'F';
  }

/****************************************************************************
*                                   END VARIATION #7
*****************************************************************************/

/****************************************************************************
*          SENDING 255 BYTES OF DATA TO PORT (BEGIN VARIATION #8)
*****************************************************************************/

VARLOG (8);

  CWRITELOG (L_TRACE, (l_log, "Sending 255 bytes to port\n"));

  rc = DOSWRITE (handle,
                 (char far *) buff3,
                 strlen (buff3),
                 (unsigned far *) &num_bytes);

  if (rc || (strlen (buff3) != num_bytes)) {
    CWRITELOG (L_FAIL, (l_log, "Error on DOSWRITE 7, rc is %#x.\n",rc));
    pass_fail = 'F';
  }

/****************************************************************************
*                                END VARIATION #8
*****************************************************************************/

/****************************************************************************
*        SEND FORM FEED  -- CONTROL CHARACTER -- (BEGIN VARIATION #9)
*****************************************************************************/

VARLOG (9);

  CWRITELOG (L_TRACE, (l_log, "Sending formfeed to port\n"));

  rc = DOSWRITE (handle, "\x0c", 1, (unsigned far *) &num_bytes);

  if (rc || ( 1 != num_bytes)) {
    CWRITELOG (L_FAIL, (l_log, "Error on formfeed, rc is %#x.\n",rc));
    pass_fail = 'F';
  }

/****************************************************************************
*                            END VARIATION #9
*****************************************************************************/

/****************************************************************************
*         PORT IS IN DEFAULT STATE AT TERMINATION OF THIS TESTCASE
*****************************************************************************/

VARLOG (0);

  rc = DOSCLOSE (handle);

  if (rc) {
    CWRITELOG (L_ABORT, (l_log, "%s was not closed, rc is %#x.\n",port,rc));
    pass_fail = 'F';
    ABORTLOG ();
  }
  else {
    CWRITELOG (L_TRACE, (l_log, "%s was closed, rc is %#x.\n",port,rc));
  }

  if (pass_fail == 'P') {
    CLOSELOG ("PASS",(l_log,"\n"));
  }
  else {
    CLOSELOG ("FAIL",(l_log,"\n"));
  }
}
