/********************** PALS-IT REXX PROLOGUE ********************************/
/*                                                                           */
/*  Testcase Name:     ITLLD.CMD                                             */
/*                                                                           */
/*  Descriptive Name:  REMOTE CALL AND DISCONNECT TEST                       */
/*                                                                           */
/*  FUNCTION TESTED:   Dial the LAN Distance server, logon to the domain,    */
/*                     Copy some files, logoff, hangup, wait, repeat.        */
/*                                                                           */
/*  TESTCASE OBJECTIVE:                                                      */
/*     DESCRIPTION:                                                          */
/*         Remote requester dials in to the LD connection server             */
/*         and logs on to the network.  It then copies 4   files from        */
/*         the DOMROOT then accesses a FTP server, then sends some           */
/*         notes via net send before hanging up the connection. The system   */
/*         will wait 3 minutes then dial in again and repeat the sequence.   */
/*                                                                           */
/*     END_OF_DESCRIPTION                                                    */
/*                                                                           */
/*     TESTABLE ITEMS:                                                       */
/*         Lan Distance and remote clients                                   */
/*                                                                           */
/*  DEPENDENCIES:                                                            */
/*         This test requires 4  files to be on the domain controller        */
/*          with the names 1k.dat, 2k.dat, 3k.dat and 4k.dat                 */
/*                                                                           */
/*  MANUAL INTERVENTION                                                      */
/*     None                                                                  */
/*                                                                           */
/*     PREREQUISITES:                                                        */
/*                                                                           */
/*     Input Parameters:                                                     */
/*                                                                           */
/*         - Count  (number of time to loop the test                         */
/*         - uid    (the machine userid to use for domain logon)             */
/*         - pw     (password for the machine useid)                         */
/*         - dom    (the name of the domain controller)                      */
/*         - phonebk(the phone book entry the remote will call)              */
/*                                                                           */
/*     Outputs:                                                              */
/*         - RC= 0 if successful      RC=8 if failed                         */
/*                                                                           */
/*     SPECIAL NOTES:                                                        */
/*                                                                           */
/*         - None.                                                           */
/*                                                                           */
/*  RESTRICTIONS:                                                            */
/*     none                                                                  */
/*                                                                           */
/*  CHANGE ACTIVITY:                                                         */
/*    Ver  Date      NAME         Comments                                   */
/*    1.0  3/21/94  B. Jones       Initial release.                          */
/*    1.0  3/21/94  R. Bassemir   Changes for the ITL async card testing     */
/*    1.1  4/01/94  R. Bassemir   Enhancements and more ITL changes          */
/*    1.2  2/12/97  R. Bassemir   Modified for auto execution                */
/*    1.3  2/14/97  R. Bassemir   Added checking and TCP/IP tests            */
/*    1.4  5/23/97  R. Bassemir   Changed log file naming convention and     */
/*                                added parameter keywords                   */
/*    1.5  6/02/97   R.Bassemir   Changes to have log written back to the    */
/*                                connection server S01 and added default    */
/*                                execution parameters                       */
/*    1.6  6/16/97   R.Bassemir   Added the boot device, remote loging,      */
/*                                history file,                              */
/*                                                                           */
/*        7/03/97  S. Hudson     Change to use OS2DRV instead of hardcode c  */
/*        7/10/97  S. Hudson     Change logfile-history file creation and    */
/*                               output lines to match other testcases.      */
/*        7/15/97  S. Hudson     Change to use common functions for methods  */
/*                               of creating history,log files, extracting   */
/*                               local system names, duration times.         */
/*        7/25/97  S. Hudson     Change to add 16KB files and compares       */
/*                               Change to add xcopy of all .KB files        */
/*        7/25/97  S. Hudson     Change to use DIAL LOCATION instead of ITL  */
/*                               to simplify customer setup requirements.    */
/*       11/03/97  S.Hudson      Change to broadcast message for recvr1      */
/*                                    instead of only to domain or server to */
/*                                    allow msg testing with SMP servers.    */
/*        5/07/99  T. Hughes  Changed the TCPIP part of the testcase to add   */
/*                                 additional error checking and for FTP to use the */
/*                                 REXXFTP commands instead of the NETRC macro*/
/*                                                                           */
/******************************-END PROLOGUE-*********************************/
arg count uid pw dom phonebk
TRACE OFF

/**************************************************************************/
/* USE OS2 ENVIRONMENT VARIABLE COMSPEC= TO FIND OS/2 BOOT DRIVE.         */
/**************************************************************************/
cmspec = value('COMSPEC',,'OS2ENVIRONMENT');
os2drv = left(cmspec,1)||':'

if (count = '?') then signal HELP

if (count = ' ') then count = 25

if (uid = ' ') then uid = 'IT01R02U'    /* set the userid if not given  */

if (pw  = ' ') then pw  = 'UPW01R02'    /* set the password if not given   */

if (dom = ' ') then dom = 'IT01D01D'    /* set the domain if not given  */

if (phonebk = ' ') then phonebk = 'DIAL LOCATION' /* set the phone book entry if not already given*/

beepit = 'Y'

/*****************************************************************************/
/*****************************************************************************/
CALL RxFuncAdd 'SysSleep', 'RexxUtil', 'SysSleep'
CALL RxFuncAdd 'SysLoadFuncs', 'RexxUtil', 'SysLoadFuncs'
CALL SysLoadFuncs
CALL RxFuncAdd 'SysFileSearch','RexxUtil','SysFileSearch'
CALL RxFuncAdd 'FtpLoadFuncs','rxFtp','FtpLoadFuncs'
CALL FtpLoadFuncs

/***************** determine NETBIOS name **local system*************/
CALL SysFileSearch 'Computername',os2drv'\ibmlan\ibmlan.ini','file.'
localname = strip(subword(file.1,3,1))

/***************** define the log file and history file *************/
logfile = os2drv'\'||substr(localname,5,3)'logs\itlld.'||substr(localname,5,3)
histfile = os2drv'\'||substr(localname,5,3)'logs\itlld.'||substr(localname,5,3)'.history'
pinglog = os2drv'\'||substr(localname,5,3)'logs\pinglog.'||substr(localname,5,3)

/***************** initialize a history file **************************/
res = lineout(histfile, '***** 'time() date()' ITLLD History *****')
res = lineout(histfile)

/***************** copy existing file to history ********************/
'copy 'histfile'+'logfile' 'histfile
'erase 'logfile

/**************** start a new log file *****************************/
res = lineout(logfile, '***** 'time() date()' ITLLD STARTING *****')
res = lineout(logfile, 'number of passes='count' user='uid' userid='pw)
res = lineout(logfile, 'domain='dom' phone book entry='phonebk)
res = lineout(logfile)
start_time = date('u') time('c')

/******* determine the next available DRIVE for a net use ******/
ndrive = nextfree()
if ndrive = 0 then
   do
      say '- There are NO free DRIVES for the NET USE '
      say '           *** This test will end now.'
      exit
   end /* do */

'cls'
errtry = 0
i = 0
startt = time()
startd = date()
sleeptime = 15
recvr1 = "/D:it01d01d"
recvr2 = "it01r01"
failmsg1 = 0
failmsg2 = 0
sleeptime = 10

/*****************************************************************************/
/*****************************************************************************/
DIAL:
errmax = 2     /* Set maximum number of retries on error before aborting job */

do while i < count
   i = i + 1
   /***********************************************************************/
   /* Dial the LAN Distance Connection server                         .   */
   /***********************************************************************/
   nowt = time()
   res = lineout(logfile,'Starting Dial operation at 'nowt' ')
   res = lineout(logfile)

   'ldist dial /D:"'||phonebk'" /U:'||uid' /P:'||pw

   if (rc = 0) then errtry = 0
   if (rc <> 0) then do             /* Log non-0 from dial operation */
      nowt = time()
      errtry = errtry + 1
      res = lineout(logfile,'Non-zero return code from dial operation.')
      res = lineout(logfile,'    rc = 'rc' Cnt = 'errtry' at 'nowt' ')
      res = lineout(logfile)
      /************************************************************************/
      /* But if it was just a busy return code, tell user we will retry soon. */
      /************************************************************************/
      if((rc = 316) | (rc = 323))  then errmax = 5
      if (errtry >= errmax) then do        /* If retry > max, fail */
         code = 'Dial operation'
         signal ERR_STOP
      end

      say 'Busy return code, going to retry the operation '
      CALL SysSleep sleeptime
      signal DIAL
   end              /* end if non-0 from dial operation */

   /***********************************************************************/
   /* Log current activity to log file                                      */
   /***********************************************************************/
   nowt = time()
   say ' Successfully connected to the LAN Distance connection server'
   res = lineout(logfile,'Dialed SERVER ************ pass 'i' at 'nowt' ')
   res = lineout(logfile)
   /***********************************************************************/
   /* Now that connected, log on to the domain controller                 */
   /***********************************************************************/
   'logon '||uid' /p:'||pw' /v:d'

   if (rc <> 0) then do
      code = "logon attempt"
      signal ERR_STOP
   end

   say 'Successfully logged on to the domain controller '

   'net use 'ndrive' DOMROOT'
   if (rc <> 0) then do
      code = "net use "
      signal ERR_STOP
   end

   say 'Successfully connected to shared directory'
   nowt = time()
   nowd = date()

   res = lineout(logfile,'Started copying files from shared directory at 'nowt' ')
   res = lineout(logfile)
   /***********************************************************************/
   /* Now copy files from the shared directory                            */
   /***********************************************************************/
   x = 1
   do while x < 10
      'copy 'ndrive'\'||x||'k.dat 'os2drv'\itlutil\infile.00'||x
      if (rc <> 0) then do
         code = "copy files"
         signal ERR_STOP
      end
      x = x * 2
   end    /* end do while x < 10 */

   nowt = time()
   x = 1
   do while x < 10
      'comp 'ndrive'\'||x||'k.dat  'os2drv'\itlutil\infile.00'||x'  <  'os2drv'\ITLUTIL\COMP.RSP'
      if (rc <> 0) then do                   /* compare failed              */
         code = "compare files"
         signal ERR_STOP
      end
      x = x * 2
   end    /* end do while x < 10 */

   say 'Finished copying files at 'nowt
   res = lineout(logfile,'Finished copying and checking files at 'nowt' ')
   res = lineout(logfile)

   /***********************************************************************/
   /* Now do some TCP/IP pings and FTP a file from a FTP server           */
   /***********************************************************************/

   address = 'it01s01'
   sleeptime = 10
     'ping 'address '56 3 >' pinglog
     CALL SysFileSearch 'packet loss', pinglog ,'ping.'
     parse upper var ping.1 . ',' . ',' percent '%' .
     packetloss = strip(percent)
     if packetloss > 0 then
       do
          say "error from ping"
          res = lineout(logfile, 'tcpip ping failed')
          res = lineout(logfile)
      code = "ping"
      signal ERR_STOP
   end
   else do
        say "Continuing normally."
        end

     userid = localname||'u'
     parse upper var userid userid
     password = 'upw'||substr(localname,3,5)
     parse upper var password password
     file = '8k.dat'

     say 'Ftp_ing to address 'address
     rc = FtpSetUser(address,userid,password)
     if rc <> 1 then
       do
         res = lineout(logfile, 'Error setting host/id/password')
         res = lineout(logfile)
         call ftpfail
       end
     say 'Recieving file ' file ' from address ' address
     rc = FtpGet(file,file,"Binary")
     if rc <> 0 then
       do
         res = lineout(logfile,'Error recieving file 'file' from address 'address)
         res = lineout(logfile)
         call ftpfail
       end
     say 'Putting file ' file ' to address ' address ' as ' localname'.ftp'
     rc = FtpPut(file,localname'.ftp',"Binary")
     if rc <> 0 then
       do
         res = lineout(logfile,'Error putting file 'file' to address 'address' as 'localname'.ftp')
         res = lineout(logfile)
         call ftpfail
       end
     else
       do
         rc = FtpLogoff()
         say "Continuing normally."
       end

   SAY' Pause for 'sleeptime' seconds'
   call SysSleep sleeptime

   say 'Finished TCP/IP and FTP exercise'

   res = lineout(logfile,'Finished the TCP/IP and FTP exercise at 'nowt' ')
   res = lineout(logfile)

   /***********************************************************************/
   /* Now send some network messages                                      */
   /***********************************************************************/

   'NET SEND 'RECVR1'  Messaging exerciser is running, pass number 'i
   IF (rc \= 0) then do
      DATETIME = DATE() TIME()
      SAY 'Message was not successfully sent to target system 'recvr1
      SAY DATETIME  'Pass number  ' i
      res = lineout(logfile, 'Unsuccessful at sending message to 'recvr1' at 'datetime' ')
      res = lineout(logfile)
      failmsg1=failmsg1+1
   end                                        /* end IF RC\=0 statement   */

   'NET SEND 'RECVR2'  Messaging exerciser is running, pass number 'i
   IF (rc \= 0) then do
      DATETIME = DATE() TIME()
      SAY 'Message was not successfully sent to target system 'recvr2
      SAY DATETIME  'Pass number  ' i
      res = lineout(logfile, 'Unsuccessful at sending message to 'recvr2' at 'datetime' ')
      res = lineout(logfile)
      failmsg2=failmsg2+1
   end                                        /* end IF RC\=0 statement   */

   SAY'There have been ' (2*i) ' messages sent.'
   SAY'...Sleeping for 'sleeptime' seconds'
   call SysSleep sleeptime

   say 'Finished messaging exercise'

   res = lineout(logfile,'Finished the messaging exercise at 'nowt' ')
   res = lineout(logfile,'--'failmsg1' messages failed to be delivered to 'recvr1' ')
   res = lineout(logfile,'--'failmsg2' messages failed to be delivered to 'recvr2' ')
   res = lineout(logfile)

   /***********************************************************************/
   /* Check to see if this is the last pass of the do loop (i=count)      */
   /***********************************************************************/
   if (i=count) then do
      res = lineout(logfile,'Test case ITLLD completed 'count' passes successfully')
      res = lineout(logfile)
      'copy 'logfile' 'ndrive'\*.*'
   end

   /***********************************************************************/
   /* Now that drop the shared directory and logoff the network           */
   /***********************************************************************/
   CALL SysSleep 3
   'net use 'ndrive' /d'
   if (rc <> 0) then do
      code = "net use /d"
      signal ERR_STOP
   end

   'logoff'
   if (rc <> 0) then do
      code = "logoff"
      signal ERR_STOP
   end

   nowt = time()
   nowd = date()
   errtry = 0

   HANGUP:
   'ldist hangup /D:"'||phonebk'"'
   if (rc = 0) then errtry = 0
   if (rc <> 0) then do
      errtry = errtry + 1
      erc = SysSleep(10)
      if (errtry < 2) then do
         res = lineout(logfile,'Non-zero return code from hangup operation rc = 'rc' ')
         res = lineout(logfile)
         signal HANGUP
      end
   end

   if (errtry >= 2) then do
      code = 'Hangup'
      signal ERR_STOP
   end
   say 'Logged off and disconnected from LAN Distance'

   /***********************************************************************/
   /* Log successful completion of hangup operation, then continue.       */
   /***********************************************************************/
   nowt = time()
   nowd = date()
   res = lineout(logfile,'Hangup operation, pass 'i' at 'nowt' on 'nowd' ')
   res = lineout(logfile)

   res = lineout(logfile,'***** Completed pass 'i' at 'nowt' on 'nowd' ')
   res = lineout(logfile)

   say 'Completed pass 'i' at 'nowt'  'nowd' ....now sleeping for 1 minutes'
   say ' '
   say ' '
   CALL SysSleep(60)
end  /* end do while i < count */

say 'End of do loop'


/*****************************************************************************/
/*****************************************************************************/
final_dial:
'ldist dial /D:"'||phonebk'" /U:'||uid' /P:'||pw  /* dial in to write log */
if (rc = 0) then errtry = 0
if (rc <> 0) then do             /* Log non-0 from dial operation */
   nowt = time()
   errtry = errtry + 1
   res = lineout(logfile,'Non-zero return code from dial operation')
   res = lineout(logfile,'--rc = 'rc' Cnt = 'errtry' at 'nowt' ')
   res = lineout(logfile)
   /* ******************************************************************** */
   /* But if it was just a busy return code, tell user we will retry soon. */
   /* ******************************************************************** */
   if((rc = 316) | (rc = 323))  then errmax = 5
   if (errtry >= errmax) then do        /* If retry > max, fail */
      code = 'Dial operation'
      signal ERR_STOP
   end
   say 'Busy return code, going to retry the operation '
   CALL SysSleep(15)
   signal final_dial
end            /* end if non-0 from dail operation */
say ' Successfully connected to the LAN Distance connection server'
/***********************************************************************/
/* Log current activity to log file                                      */
/***********************************************************************/
nowt = time()
res = lineout(logfile,'Dialed SERVER ************ pass 'i' at 'nowt' ')
res = lineout(logfile)
/***********************************************************************/
/* Now that connected, log on to the domain controller                 */
/***********************************************************************/
'logon '||uid' /p:'||pw' /v:d'
if (rc <> 0) then do
   code = "logon attempt"
   signal ERR_STOP
end

say 'Successfully logged on to the domain controller '

res = lineout(logfile, '***** 'time() date()' ITLLD Completed successfully *****')
res = lineout(logfile)

'NET USE 'ndrive' S01LOGS'            /* get network resource        */
'copy 'logfile' 'ndrive'*.*'          /* copy log file over          */

CALL SysSleep 3

'NET USE 'ndrive' /DELETE'            /* drop the network resource   */

/***********************************************************************/
/* Completed final copy of log file, now hang up the connection        */
/***********************************************************************/
'ldist hangup /D:"'||phonebk'"'

'copy 'os2drv'\startup.hld 'os2drv'\startup.cmd'

'ldshuttl lan'

'cls'
say ''
say ''
say '[1;37;45mͻ';
say ' ITLLD.CMD - Completed successfully.                                 ';
say '             System setup for LAN connection on reboot.              ';
say '                                                                     ';
say ' The system will reboot after waiting for disk processing to finish. ';
say '                                                                     ';
say ' PLEASE WAIT --- Let program reboot system after finishing updates.  ';
say 'ͼ[0;40;37m';
say ''
say ''

c = 0
r = 15

DO 45
   pos = SysCurPos(r,c)
   say '.'
   c=c+1
   call SysSleep 1 ;
END

os2drv'\os2\swboot r'

exit

/*****************************************************************************/
/*****************************************************************************/
ftpfail:
     say "Error from ftp"
     res = lineout(logfile, 'TCPIP FTP Failed')
     res = lineout(logfile)
     code = 'ftp'
     signal ERR_STOP
end

ERR_STOP:
stopt = time()
stopd = date()
res = lineout(logfile,'Program execution halted due to error on 'code' at 'stopt' on 'stopd' ')
res = lineout(logfile)
'cls'
say ' '
say ' '
say ' EEEEEEE     RRRRRR       RRRRRR        OOOOOO        RRRRRR       !!! '
say ' E           R     R      R     R      O      O       R     R      !!! '
say ' E           R     R      R     R      O      O       R     R      !!! '
say ' EEEEE       RRRRRR       RRRRRR       O      O       RRRRRR       !!! '
say ' E           R     R      R     R      O      O       R     R      !!! '
say ' E           R     R      R     R      O      O       R     R      !!! '
say ' EEEEEEE     R     R      R     R       OOOOOO        R     R       !  '
say ' '
say '                          >> TEST CASE FAILED. <<'
say ' '
say '    Check \R02LOGS\ITLLD.R02 logfile for test case execution data'
say '    Test started at: 'startt ' on 'startd
say '    Test FAILED  at: 'stopt ' on 'stopd
say ' '
select
 when code = 'logon attempt' then 'ldist hangup /D:"'||phonebk'"'
 when code = 'net use' then do
             'logoff'
             'ldist hangup /D:"'||phonebk'"'
             end
 when code = 'copy files' then do
             'logoff'
             'ldist hangup /D:"'||phonebk'"'
             end
 when code = 'compare files' then do
             res = lineout(logfile, '***** ITLLD Failed on file compares ****')
             res = lineout(logfile)
             'copy 'logfile' 'ndrive'*.*'          /* copy log file over          */
             'logoff'
             'ldist hangup /D:"'||phonebk'"'
             end
 otherwise nop
end
signal ENDIT

/*****************************************************************************/
/*****************************************************************************/
HELP:
say 'This program will dial a LAN Distance server, log on to the'
say 'LAN Server domain, copy some files, compare the files, log off from the '
say 'domain, access a FTP server and send some network messages before hanging '
say 'up the connection.  '
say ' '
say '   ITLLD count userid password domain phonebk '
say ' '
say 'count = the number of times you want to repeat this cycle default is 25'
say 'userid =  the user ID for the LAN Distance server and the domain access'
say '          The default is IT01R02U'
say 'password = the password for LAN Distance and domain (must be the same) '
say '           The default is UPW01R02'
say 'domain = the domain controller that is being contacted once connected'
say '         The default is IT01D01D'
say 'phonebk = the Phonebook entry that you are calling. The default is ITL'
say ' '
say 'Notes: - The parameters are position dependent. If you wish to pass'
say '         a different domain, you must specify the count, userid, and '
say '         password parameters.'
say '       - The Phonebook entry is case sensitive and must match the LAN '
say '         Distance phone book entry.'
exit

/*****************************************************************************/
/*****************************************************************************/
ENDIT:
 if (beepit = 'Y') then do forever
    call beep 3000,300
    call beep 1000,300
    call syssleep(1)
 end            /* End do forever loop */
exit
